\name{lazyload}
\title{Lazy Loading of Packages}
\usage{
code2LazyLoadDB(package, lib.loc = NULL, 
    keep.source = getOption("keep.source.pkgs"))
makeLazyLoading(package, lib.loc = NULL, compress = TRUE,
    keep.source = getOption("keep.source.pkgs"))
rda2LazyLoadDB(package, lib.loc = NULL)
makeLazyLoadDB(from, filebase, compress = TRUE, ascii = FALSE, variables)
}
\alias{code2LazyLoadDB}
\alias{makeLazyLoading}
\alias{rda2LazyLoadDB}
\alias{makeLazyLoadDB}
\arguments{
  \item{package}{package name string}
  \item{lib.loc}{library trees, as in \code{library}}
  \item{keep.source}{logical; should sources be kept when saving from source}
  \item{compress}{logical; whether to compress entries.}
  \item{from}{named list of values or environment.}
  \item{filebase}{character; base path of data base.}
  \item{ascii}{logical; whether to use text or binary serialization.}
  \item{variables}{character; optional list of variable names when
                   \code{from} is an enfironment.}
}
\description{
  Tools for lazy loading of packages from a data base.
}
\details{
  This package provides tools to set up packages for lazy loading from a
  data base.  For packages other than base you can use
  \code{makeLazyLoading(package)} to convert them to use lazy loading.

  For base you need to start R with no packages loaded,  e.g. by setting
  \code{R_DEFAULT_PACKAGES} to \code{NULL}, and then source
  \code{makebasedb.R}; this file is provided in the package diractory.
  This builds a data base.  Once the data base has been built, use
  makeLazyLoading("base") to convert base to use lazy loading.

  A simple \code{make} seems sufficient to undo this for base and base
  packages other than \code{methods} and perhaps \code{mle}.  For
  \code{methods} (and presumably others created with \code{--save}) it
  appears that you need to remove \code{methods/R/methods} and then use
  \code{make}.  You may also need more radical action for recommended
  packages.
}
\examples{
  # set up package "base" for lazy loading (must have no packages loaded)
  \dontrun{
    source(file.path(.find.package("lazyload"),"makebasedb.R"))
    library(lazyload)
    makeLazyLoading("base")
  }

  # set up package "ctest" for lazy loading
  \dontrun{
    library(lazyload)
    makeLazyLoading("ctest")
  }

  # set up all base packages for lazy loading
  \dontrun{
    library(lazyload)
    for (p in rev(installed.packages(priority="base")[,"Package"])) {
        cat(paste("converting", p, "..."))
        makeLazyLoading(p)
        cat("done\n")
    }
  }
}
\keyword{programming}
\author{Luke Tierney}
